@@ -2,11 +2,13 @@ CALL_ID_STACK_CONTEXT_KEY = 'call_id_stack'
 AUTH_TOKEN_CONTEXT_KEY = 'auth_token'
 LANGUAGE_CONTEXT_KEY = 'language'
 USER_ID_CONTEXT_KEY = 'user_id'
+USER_AGENT_CONTEXT_KEY = 'user_agent'
 
 
 NAMEKO_CONTEXT_KEYS = (
     LANGUAGE_CONTEXT_KEY,
     USER_ID_CONTEXT_KEY,
+    USER_AGENT_CONTEXT_KEY,
     AUTH_TOKEN_CONTEXT_KEY,
     CALL_ID_STACK_CONTEXT_KEY,
 )
