@@ -8,9 +8,10 @@ log = logging.getLogger(__name__)
 
 
 class ServiceDocProcessor(object):
-    def __init__(self, output, service_loader_function):
+    def __init__(self, output, service_loader_function, event_loader_function):
         self.output = path(output)
         self.service_loader_function = service_loader_function
+        self.event_loader_function = event_loader_function
 
     def write_docs(self):
         if not self.output.exists():
@@ -19,7 +20,8 @@ class ServiceDocProcessor(object):
             raise ValueError('The provided output folder is not empty.')
 
         extractor = MethodExtractor(
-            self.service_loader_function
+            self.service_loader_function,
+            self.event_loader_function,
         )
         collection = extractor.extract()
 
